__version__ = '1.0.1'
__author__ = 'ZephyrOff  (Alexandre Pajak)'
__descriptor__ = 'Système de fichier managé pour le contrôle des actions sur un fichier'
__lastupdate__ = '16/12/2022'
__releasenote__ = 'Correction permissions mode'

from .ManagedFile import *